@@ -1,4 +1,4 @@
-from typing import Dict, Callable, Any, Optional
+from typing import Any, Callable, Dict, Optional, Sequence
 
 from airflow.providers.common.sql.sensors.sql import SqlSensor
 from airflow.utils.decorators import apply_defaults
@@ -6,6 +6,8 @@ from airflow_clickhouse_plugin.hooks.clickhouse_hook import ClickHouseHook
 
 
 class ClickHouseSqlSensor(SqlSensor):
+    template_fields: Sequence[str] = ('sql',)
+    template_ext: Sequence[str] = ('.sql',)
     default_conn_name = ClickHouseHook.default_conn_name
 
     def __init__(
